#
#  FILE NAME:
#      operations.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# P3 imports:
from p3.base.string_helpers import safe_fmt
from p3.data.error import DataModuleError


def find_row_opt( table, expr=None ):
    rows = (table.rows if expr is None else table.find_rows( expr ))
    cnt = len(rows)
    if (cnt > 1):
        raise DataModuleError( DataModuleError.codes.multiple_rows_found,
                               safe_fmt( "Multiple rows found for expression: %s", repr(expr) ) )
    else:
        return (rows[0] if cnt else None)


def find_row_req( table, expr=None ):
    rows = (table.rows if expr is None else table.find_rows( expr ))
    cnt = len(rows)
    if (cnt > 1):
        raise DataModuleError( DataModuleError.codes.multiple_rows_found,
                               safe_fmt( "Multiple rows found for expression: %s", repr(expr) ) )
    elif not cnt:
        raise DataModuleError( DataModuleError.codes.row_not_found,
                               safe_fmt( "Required row not found with expression: %s", repr(expr) ))
    else:
        return rows[0]


def extract_column_values( table, col_spec ):
    col = table.resolve_columns( col_spec )[0]

    return tuple(r[col.index] for r in table.rows)
